    .. note::

        ``tcdel`` delete mangle tables in ``iptables``.
        (any other tables are not affected).


``tcdel`` command help
~~~~~~~~~~~~~~~~~~~~~~

.. include:: tcdel_help_output.txt
